Several functions simply extend the functionalities of other functions
commonly used for the analysis of pedometric data. It should be noted that
changes are likely to occur quite often and the use of this package as a
dependency for other packages is strongly discouraged.ll{
Package: pedometrics
Type: Package
Version: 0.6-4
Date: 2015-11-28
License: GPL (>= 2)
}