Learn R Programming

pedometrics (version 0.6-4)

vgmICP: Initial covariance parameters (ICP)

Description

Guess the initial values for the covariance parameters required to fit a variogram model.

Usage

vgmICP(z, coords, lags, max.dist = Inf, method = "a", min.npairs = 30,
  model = "RMexp", nu, plotit = FALSE, ...)

Arguments

z
Numeric vector with the values of the response variable.
coords
Data frame or matrix with the projected x- and y-coordinates.
lags
Numeric scalar defining a the width of the lag-distance classes, or a numeric vector with the upper bounds the lag-distance classes.
max.dist
Positive numeric defining the maximum distance up to which lag-distance classes should be computed. Defaults to max.dist = Inf.
method
Character keyword defining the method used for guessing the initial covariance parameters. Defauls to method = "a". See Details for more information.
min.npairs
Positive integer defining the minimum number of point-pairs required so that a lag-distance class is used for guessing the initial covariance parameters. Defaults to min.npairs = 30.
model
Character keyword defining the variogram model that will be fitted to the data. Currently, most basic variogram models provided by the RandomFields-package are accepted. See Details of
nu
Smoothness parameter $\nu$ of the Whittle-Matérn model. See RMmodel.
plotit
Should the guessed initial covariance parameters be plotted along with the sample variogram? Defaults to plotit = FALSE.
...
Further arguments passed to sample.variogram, such as estimator, a character keyword defining the estimator for computing the sample variogram. The default estimator is Genton'

Value

  • A vector of numeric values: the guesses for the covariance parameters nugget, partial sill, and range.

concept

variogram

Details

There are five methods two guess the initial covariance parameters (ICP). Two of them ("a" and "b") rely a sample variogram with exponentially spaced lag-distance classes, while the other three ("b", "d", and "e") use equidistant lag-distance classes (see vgmLags). All of them are https://en.wikipedia.org/wiki/Heuristic{heuristic}.

Method "a" was developed in-house, and is the most elaborated of them, specially for guessing the nugget variance. Method "c" is implemented in the automap-package and was developed by http://dx.doi.org/10.1016/j.cageo.2008.10.011{Hiemstra et al. (2009)}.

Method "b" was proposed by http://dx.doi.org/10.1016/0098-3004(95)00095-X{Jian et al. (1996)} and is implemented in https://support.sas.com/documentation/cdl/en/statug/63347/HTML/default/viewer.htm#statug_variogram_a0000000593.htm{SAS/STAT(R) 9.22}. Method "d" was developed by http://dx.doi.org/10.1007/s11004-012-9434-1{Desassis & Renard (2012)}. Method "e" was proposed by http://www.ccgalberta.com/ccgresources/report05/2003-122-varfit.pdf{Larrondo et al. (2003)} and is implemented in the VARFIT module of http://www.gslib.com/{GSLIB}.

References

Desassis, N. & Renard, D. Automatic variogram modelling by iterative least squares: univariate and multivariate cases. Mathematical Geosciences. Springer Science $+$ Business Media, v. 45, p. 453-470, 2012.

Hiemstra, P. H.; Pebesma, E. J.; Twenhöfel, C. J. & Heuvelink, G. B. Real-time automatic interpolation of ambient gamma dose rates from the Dutch radioactivity monitoring network. Computers & Geosciences. Elsevier BV, v. 35, p. 1711-1721, 2009.

Jian, X.; Olea, R. A. & Yu, Y.-S. Semivariogram modelling by weighted least squares. Computers & Geosciences. Elsevier BV, v. 22, p. 387-397, 1996.

Larrondo, P. F.; Neufeld, C. T. & Deutsch, C. V. VARFIT: a program for semi-automatic variogram modelling. Edmonton: Department of Civil and Environmental Engineering, University of Alberta, p. 17, 2003.

See Also

vgmLags, sample.variogram, autofitVariogram

Examples

Run this code
data(meuse, package = "sp")
icp <- vgmICP(z = log(meuse$copper), coords = meuse[, 1:2])

Run the code above in your browser using DataLab