Learn R Programming

pedometrics (version 0.6-4)

vgmSCV: Spatially correlated variance (SCV)

Description

Compute the proportion of the variance that is spatially correlated.

Usage

## S3 method for class 'variomodel':
vgmSCV(obj, digits = 4)

## S3 method for class 'variogramModel': vgmSCV(obj, digits = 4)

## S3 method for class 'georob': vgmSCV(obj, digits = 4)

Arguments

obj
Variogram model fitted with available function in geostatistical packages such as gstat, geoR, and georob.
digits
Integer indicating the number of decimal places to be used.

Value

  • Numeric value indicating the proportion of the variance that is spatially correlated.

concept

variogram

See Also

vgmLags