vgmICP(z, coords, lags, max.dist = Inf, method = "a", min.npairs = 30,
model = "RMexp", nu, plotit = FALSE, ...)max.dist = Inf.method = "a". See
min.npairs = 30.RMmodel.plotit = FALSE.sample.variogram, such as estimator, a character
keyword defining the estimator for computing the sample variogram. The
default estimator is Genton'"a" and "b") rely a sample variogram with
exponentially spaced lag-distance classes, while the other three ("b",
"d", and "e") use equidistant lag-distance classes (see
vgmLags). All of them are
Method "a" was developed in-house, and is the most elaborated of them,
specially for guessing the nugget variance. Method "c" is implemented
in the
Method "b" was proposed by
"d" was developed by
"e" was proposed by
Hiemstra, P. H.; Pebesma, E. J.; Twenhöfel, C. J. & Heuvelink, G. B. Real-time automatic interpolation of ambient gamma dose rates from the Dutch radioactivity monitoring network. Computers & Geosciences. Elsevier BV, v. 35, p. 1711-1721, 2009.
Jian, X.; Olea, R. A. & Yu, Y.-S. Semivariogram modelling by weighted least squares. Computers & Geosciences. Elsevier BV, v. 22, p. 387-397, 1996.
Larrondo, P. F.; Neufeld, C. T. & Deutsch, C. V. VARFIT: a program for semi-automatic variogram modelling. Edmonton: Department of Civil and Environmental Engineering, University of Alberta, p. 17, 2003.
vgmLags,
sample.variogram,
autofitVariogramdata(meuse, package = "sp")
icp <- vgmICP(z = log(meuse$copper), coords = meuse[, 1:2])Run the code above in your browser using DataLab