Guess the initial values for the covariance parameters required to fit a variogram model.
vgmICP(
z,
coords,
lags,
cutoff = 0.5,
method = "a",
min.npairs = 30,
model = "matern",
nu = 0.5,
estimator = "qn",
plotit = FALSE
)Numeric vector with the values of the response variable for which the initial values for the covariance parameters should be guessed.
Data frame or matrix with the projected x- and y-coordinates.
Numeric scalar defining the width of the lag-distance classes, or a numeric vector with the
lower and upper bounds of the lag-distance classes. If missing, the lag-distance classes are computed using
vgmLags. See ‘Details’ for more information.
Numeric value defining the fraction of the diagonal of the
rectangle that spans the data (bounding box) that should be used to set the
maximum distance up to which lag-distance classes should be computed.
Defaults to cutoff = 0.5, i.e. half the diagonal of the bounding box.
Character keyword defining the method used for guessing the initial covariance parameters.
Defaults to method = "a". See ‘Details’ for more information.
Positive integer defining the minimum number of point-pairs required so that a
lag-distance class is used for guessing the initial covariance parameters. Defaults to min.npairs = 30.
Character keyword defining the variogram model that will be fitted to the data. Currently,
most basic variogram models are accepted. See cov.spatial for more information. Defaults
to model = "matern".
numerical value for the additional smoothness parameter \(\nu\) of the correlation function. See
RMmodel and argument kappa of cov.spatial for more
information.
Character keyword defining the estimator for computing the sample variogram, with options
"qn", "mad", "matheron", and "ch". Defaults to estimator = "qn". See
sample.variogram for more details.
Should the guessed initial covariance parameters be plotted along with the sample variogram?
Defaults to plotit = FALSE.
A vector of numeric values: the guesses for the covariance parameters nugget, partial sill, and range.
There are five methods two guess the initial covariance parameters (ICP). Two of them, "a" and
"c", rely a sample variogram with exponentially spaced lag-distance classes, while the other three, "b",
"d", and "e", use equidistant lag-distance classes (see vgmLags). All of them
are heuristic.
Method "a" was developed in-house and is the most elaborated of them, specially for guessing the nugget
variance.
Method "b" was proposed by Jian et al. (1996) and
is implemented in SAS/STAT(R) 9.22.
Method "c" is implemented in the automap-package and was developed by
Hiemstra et al. (2009).
Method "d" was developed by Desassis & Renard (2012).
Method "e" was proposed by Larrondo et al. (2003) and is implemented in the VARFIT module of GSLIB.
Desassis, N. & Renard, D. Automatic variogram modelling by iterative least squares: univariate and multivariate cases. Mathematical Geosciences. Springer Science \(+\) Business Media, v. 45, p. 453-470, 2012.
Hiemstra, P. H.; Pebesma, E. J.; Twenh<U+00F6>fel, C. J. & Heuvelink, G. B. Real-time automatic interpolation of ambient gamma dose rates from the Dutch radioactivity monitoring network. Computers & Geosciences. Elsevier BV, v. 35, p. 1711-1721, 2009.
Jian, X.; Olea, R. A. & Yu, Y.-S. Semivariogram modelling by weighted least squares. Computers & Geosciences. Elsevier BV, v. 22, p. 387-397, 1996.
Larrondo, P. F.; Neufeld, C. T. & Deutsch, C. V. VARFIT: a program for semi-automatic variogram modelling. Edmonton: Department of Civil and Environmental Engineering, University of Alberta, p. 17, 2003.
# NOT RUN {
data(meuse, package = "sp")
icp <- vgmICP(z = log(meuse$copper), coords = meuse[, 1:2])
# }
Run the code above in your browser using DataLab